function dx = rosslerc(t,x,flag,C,a,Dw)
     % function dx = rossler(t,x,flag,C,a,Dw)
     % This models the behaviour of two coupled Rossler systems
     %  The degree of coupling is given by parameter C
     % whereas the frequence mismatch is given by Dw
     % and the phase/non-phase coherency is determined by a
     % a=0.16 means phase coherent
     % a=0.293 means no phase coherence
     
     dx = zeros(6,1);    % a column vector
     dx(1) = -(1+Dw)*x(2)-x(3)+C*(x(4)-x(1));
     dx(2) = (1+Dw)*x(1)+a*x(2);
     dx(3) = 0.1+x(3)*(x(1)-8.5);
     
     dx(4) = -(1-Dw)*x(5)-x(6)+C*(x(1)-x(4));
     dx(5) = (1-Dw)*x(4)+a*x(5);
     dx(6) = 0.1+x(6)*(x(4)-8.5);